@@ -166,7 +166,7 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
     # Plot points
     if (type == 'points'){
         if (qi == "Hazard Rate"){
-            if (!is.null(obj$Strata)) {
+            if ('strata' %in% names(obj)) {
                 p <- ggplot(obj, aes(x = Time, y = HRate,
                         colour = factor(HRValue))) +
                         geom_point(aes(alpha = PercRank), size = psize) +
@@ -176,7 +176,7 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
                             guide = legend) +
                         scale_alpha_continuous(range = c(0, alpha),
                             guide = FALSE)
-            } else if (is.null(obj$Strata)){
+            } else if (!('strata' %in% names(obj))){
                 p <- ggplot(obj, aes(Time, HRate, colour = factor(HRValue))) +
                         geom_point(shape = 21, aes(alpha = PercRank),
                             size = psize) +
@@ -216,7 +216,7 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
     # Plot lines
     else if (type == 'lines'){
         if (qi == "Hazard Rate"){
-            if (!is.null(obj$Strata)) {
+            if ('strata' %in% names(obj)) {
                 p <- ggplot(obj, aes(x = Time, y = HRate,
                         colour = factor(HRValue))) +
                         geom_line(aes(group = interaction(SimID,
@@ -228,7 +228,7 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
                                           guide = legend) +
                         scale_alpha_continuous(range = c(0, alpha),
                             guide = FALSE)
-            } else if (is.null(obj$Strata)){
+            } else if (!('strata' %in% names(obj))){
                 p <- ggplot(obj, aes(Time, HRate, colour = factor(HRValue))) +
                     geom_line(aes(group = interaction(SimID, factor(HRValue)),
                                 alpha = PercRank), shape = 21, size = psize) +
@@ -274,7 +274,7 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
     else if (type == 'ribbons'){
         suppressWarnings(
         if (qi == "Hazard Rate"){
-            if (!is.null(obj$Strata)) {
+            if ('strata' %in% names(obj)) {
                 obj <- MinMaxLines(df = obj, hr = TRUE, strata = TRUE)
                 p <- ggplot(obj, aes(x = Time, y = HRate,
                         colour = factor(HRValue), fill = factor(HRValue))) +
@@ -288,7 +288,7 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
                             guide = legend) +
                         scale_fill_brewer(palette = spalette, name = leg.name,
                             guide = legend)
-            } else if (is.null(obj$Strata)){
+            } else if (!('strata' %in% names(obj))){
                 obj <- MinMaxLines(df = obj, hr = TRUE)
                 p <- ggplot(obj, aes(Time, Median, colour = factor(HRValue),
                         fill = factor(HRValue))) +
